// Copyright (c) 2018-2021 The MobileCoin Foundation

//! Errors which can be generated by this crate

use core::result::Result as StdResult;
use displaydoc::Display;

/// A type alias for results of fallible computation.
pub type Result<T> = StdResult<T, Error>;

/// Errors which can occur when a field isn't well formed.
#[derive(Debug, Display, Eq, Hash, PartialEq, PartialOrd, Ord)]
pub enum Error {
    /// The Fog Report URL is too long
    ReportUrlLength,
    /// The Fog Report ID is too long
    ReportIdLength,
    /// The signature over Fog authority signatures
    SignatureLength,
    /// The Fog authority subjectPublicKeyInfo bytes are too long
    AuthoritySubjectLength,
    /// A Slip-0010 key could not be generated
    Slip0010Keygen,
}
